@@ -660,6 +660,8 @@ static GtkWidget *create_gcb_pos_opts()
 #include <dirent.h>
 #endif
 
+GtkWidget *gtk_hpaned_new (void);
+
 void create_gtablist_window (void)
 {
   if (gtablist_window) {
@@ -682,7 +684,6 @@ void create_gtablist_window (void)
                       G_CALLBACK (callback_win_delete), NULL);
 
   vbox = gtk_vbox_new (FALSE, 0);
-  gtk_orientable_set_orientation(GTK_ORIENTABLE(vbox), GTK_ORIENTATION_VERTICAL);
   gtk_container_add (GTK_CONTAINER (gtablist_window), vbox);
 
   sw = gtk_scrolled_window_new (NULL, NULL);
@@ -778,7 +779,7 @@ void create_gtablist_window (void)
 
   GtkWidget *hbox_phonetic_speak = gtk_hbox_new(FALSE, 10);
   gtk_box_pack_start (GTK_BOX (vboxL), hbox_phonetic_speak , FALSE, FALSE, 0);
-  GtkWidget *label_phonetic_speak = gtk_label_new(_(_L("輸入時念出發音")));
+  GtkWidget *label_phonetic_speak = gtk_label_new(_(_L("念出發音(初始)")));
   gtk_box_pack_start (GTK_BOX (hbox_phonetic_speak), label_phonetic_speak , FALSE, FALSE, 0);
   check_button_phonetic_speak = gtk_check_button_new ();
   gtk_box_pack_start (GTK_BOX (hbox_phonetic_speak), check_button_phonetic_speak, FALSE, FALSE, 0);
@@ -900,7 +901,6 @@ void create_gtablist_window (void)
   }
 
   hbox = gtk_hbox_new (TRUE, 4);
-  gtk_grid_set_column_homogeneous(GTK_GRID(hbox), TRUE);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
   button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
@@ -914,17 +914,11 @@ void create_gtablist_window (void)
   button2 = gtk_button_new_from_stock (GTK_STOCK_OK);
   g_signal_connect (G_OBJECT (button2), "clicked",
                     G_CALLBACK (cb_ok), model);
-#if !GTK_CHECK_VERSION(2,91,2)
   if (button_order)
     gtk_box_pack_end (GTK_BOX (hbox), button2, TRUE, TRUE, 0);
   else
     gtk_box_pack_start (GTK_BOX (hbox), button2, TRUE, TRUE, 0);
-#else
-  if (button_order)
-    gtk_grid_attach_next_to (GTK_BOX (hbox), button2, button, GTK_POS_LEFT, 1, 1);
-  else
-    gtk_grid_attach_next_to (GTK_BOX (hbox), button2, button, GTK_POS_RIGHT, 1, 1);
-#endif
+
 #if UNIX
   gtk_window_set_default_size (GTK_WINDOW (gtablist_window), 480, 450);
 #else
